@@ -257,16 +257,16 @@ impl fmt::Display for Modelo {
 #[derive(Clone, Copy, Debug, Eq, Hash, Ord, PartialEq, PartialOrd)]
 pub enum Servico {
     StatusServico,
-    Envio,
-    ConsultaRecibo,
+    ConsultaProtocolo,
+    ConsultaAutorizacao,
     ConsultaCadastro,
+    Envio,
     Cce,
     Epec,
     Manifestacao,
     Cancelamento,
     CancelamentoSubstituicao,
     Inutilizacao,
-    ConsultaXml,
     DistribuicaoDfe,
     UrlQrCode,
     UrlConsultaNfce,
@@ -277,16 +277,16 @@ impl fmt::Display for Servico {
         use super::Servico::*;
         match *self {
             StatusServico => write!(f, "Status Serviço"),
-            Envio => write!(f, "Envio"),
-            ConsultaRecibo => write!(f, "Consulta Recibo"),
+            ConsultaProtocolo => write!(f, "Consulta protocolo"),
+            ConsultaAutorizacao => write!(f, "Consulta Recibo"),
             ConsultaCadastro => write!(f, "Consulta Cadastro"),
+            Envio => write!(f, "Envio"),
             Cce => write!(f, "CC-e"),
             Epec => write!(f, "EPEC"),
             Manifestacao => write!(f, "Manifestação"),
             Cancelamento => write!(f, "Cancelamento"),
             CancelamentoSubstituicao => write!(f, "Cancelamento Substituição"),
             Inutilizacao => write!(f, "Inutilização"),
-            ConsultaXml => write!(f, "Consulta XML"),
             DistribuicaoDfe => write!(f, "Distribuição DF-e"),
             UrlQrCode => write!(f, "URL QRCode"),
             UrlConsultaNfce => write!(f, "URL Consulta NFC-e"),
@@ -301,16 +301,16 @@ impl Servico {
         let ver = self.versao_url();
         match *self {
             StatusServico => format!("NfeStatusServico_{}", ver),
-            Envio => format!("NfeAutorizacao_{}", ver),
-            ConsultaRecibo => format!("NFeRetAutorizacao_{}", ver),
+            ConsultaProtocolo => format!("NfeConsultaProtocolo_{}", ver),
+            ConsultaAutorizacao => format!("NFeRetAutorizacao_{}", ver),
             ConsultaCadastro => format!("NfeConsultaCadastro_{}", ver),
+            Envio => format!("NfeAutorizacao_{}", ver),
             Cce => format!("RecepcaoEvento_{}", ver),
             Epec => format!("RecepcaoEvento_{}", ver),
             Manifestacao => format!("RecepcaoEvento_{}", ver),
             Cancelamento => format!("RecepcaoEvento_{}", ver),
             CancelamentoSubstituicao => format!("RecepcaoEvento_{}", ver),
             Inutilizacao => format!("NfeInutilizacao_{}", ver),
-            ConsultaXml => format!("NfeConsultaProtocolo_{}", ver),
             DistribuicaoDfe => format!("NFeDistribuicaoDFe_{}", ver),
             UrlQrCode => "URL-QRCode".to_string(),
             UrlConsultaNfce => "URL-ConsultaNFCe".to_string(),
@@ -322,16 +322,16 @@ impl Servico {
         use super::Servico::*;
         match *self {
             StatusServico => Some("NFeStatusServico4"),
-            Envio => Some("NFeAutorizacao4"),
-            ConsultaRecibo => Some("NFeRetAutorizacao4"),
+            ConsultaProtocolo => Some("NFeConsultaProtocolo4"),
+            ConsultaAutorizacao => Some("NFeRetAutorizacao4"),
             ConsultaCadastro => Some("CadConsultaCadastro4"),
+            Envio => Some("NFeAutorizacao4"),
             Cce => Some("NFeRecepcaoEvento4"),
             Epec => Some("NFeRecepcaoEvento4"),
             Manifestacao => Some("RecepcaoEvento"),
             Cancelamento => Some("RecepcaoEvento"),
             CancelamentoSubstituicao => Some("RecepcaoEvento"),
             Inutilizacao => Some("NFeInutilizacao4"),
-            ConsultaXml => Some("NFeConsultaProtocolo4"),
             DistribuicaoDfe => Some("NFeDistribuicaoDFe"),
             UrlQrCode => Some("NfeConsultaQR"),
             UrlConsultaNfce => None,
@@ -344,16 +344,16 @@ impl Servico {
         use super::VersaoUrl::*;
         match *self {
             StatusServico => Ver400,
-            Envio => Ver400,
-            ConsultaRecibo => Ver400,
+            ConsultaProtocolo => Ver400,
+            ConsultaAutorizacao => Ver400,
             ConsultaCadastro => Ver400,
+            Envio => Ver400,
             Cce => Ver400,
             Epec => Ver400,
             Manifestacao => Ver400,
             Cancelamento => Ver400,
             CancelamentoSubstituicao => Ver400,
             Inutilizacao => Ver400,
-            ConsultaXml => Ver400,
             DistribuicaoDfe => Ver101,
             UrlQrCode => Ver400,
             UrlConsultaNfce => Ver400,
